Transcription coregulator activity
The activity unit for a transcription coregulator is:
o

o

MF: a child of transcription coregulator activity (GO:0003712):
▪

transcription coactivator activity (GO:0003713)

▪

transcription corepressor activity (GO:0003714)

Context:
▪

has input: the transcription factor regulated, when known.

▪

BP in which this transcriptional event is involved

▪

CC: this activity occurs in the nucleus.

●

The causal relation between the transcription coregulator activity and the transcription
factor activity unit is ‘directly positively regulates’ or 'directly negatively regulates.

●

If the causal relation between the coregulator and the target gene regulated needs to be
captured, the causal relation is: ‘indirectly positively regulates’ or 'indirectly negatively
regulates’, since there are many steps between the regulation of transcription and the
activity of the target protein.

Example: GO:0003714 transcription corepressor activity

Example: GO:0003713 transcription coactivator activity

Example: GO:0003712 transcription coregulator activity (BMAL1 binds
specifically DNA)

Example: Coregulator of an unknown transcription factor

Review information
To be reviewed date:
Created by: Cristina Casals

